EXPORTS
	??0RRtaData@ReferenceTestAgent@@QAE@XZ @ 1 NONAME ; ReferenceTestAgent::RRtaData::RRtaData(void)
	??0RRtaRights@ReferenceTestAgent@@QAE@XZ @ 2 NONAME ; ReferenceTestAgent::RRtaRights::RRtaRights(void)
	?AddRightsL@RRtaRights@ReferenceTestAgent@@QAEXAAVCRightsObject@2@@Z @ 3 NONAME ; void ReferenceTestAgent::RRtaRights::AddRightsL(class ReferenceTestAgent::CRightsObject &)
	?ClearAllRightsL@RRtaRights@ReferenceTestAgent@@QAEXXZ @ 4 NONAME ; void ReferenceTestAgent::RRtaRights::ClearAllRightsL(void)
	?Connect@RRtaRights@ReferenceTestAgent@@QAEHXZ @ 5 NONAME ; int ReferenceTestAgent::RRtaRights::Connect(void)
	?DataSize@RRtaData@ReferenceTestAgent@@QAEHAA_J@Z @ 6 NONAME ; int ReferenceTestAgent::RRtaData::DataSize(long long &)
	?DumpRightsDatabaseL@RRtaRights@ReferenceTestAgent@@QAEXABVTDesC16@@@Z @ 7 NONAME ; void ReferenceTestAgent::RRtaRights::DumpRightsDatabaseL(class TDesC16 const &)
	?EvaluateIntentL@RRtaData@ReferenceTestAgent@@QAEXW4TIntent@ContentAccess@@@Z @ 8 NONAME ; void ReferenceTestAgent::RRtaData::EvaluateIntentL(enum ContentAccess::TIntent)
	?ExecuteIntentL@RRtaData@ReferenceTestAgent@@QAEXW4TIntent@ContentAccess@@@Z @ 9 NONAME ; void ReferenceTestAgent::RRtaData::ExecuteIntentL(enum ContentAccess::TIntent)
	?GetAttribute@RRtaData@ReferenceTestAgent@@QBEHHAAH@Z @ 10 NONAME ; int ReferenceTestAgent::RRtaData::GetAttribute(int, int &) const
	?GetAttributeSet@RRtaData@ReferenceTestAgent@@QBEHAAVRAttributeSet@ContentAccess@@@Z @ 11 NONAME ; int ReferenceTestAgent::RRtaData::GetAttributeSet(class ContentAccess::RAttributeSet &) const
	?GetStringAttribute@RRtaData@ReferenceTestAgent@@QBEHHAAVTDes16@@@Z @ 12 NONAME ; int ReferenceTestAgent::RRtaData::GetStringAttribute(int, class TDes16 &) const
	?GetStringAttributeSet@RRtaData@ReferenceTestAgent@@QBEHAAVRStringAttributeSet@ContentAccess@@@Z @ 13 NONAME ; int ReferenceTestAgent::RRtaData::GetStringAttributeSet(class ContentAccess::RStringAttributeSet &) const
	?Open@RRtaData@ReferenceTestAgent@@QAEHAAVRFile@@ABVTDesC16@@@Z @ 14 NONAME ; int ReferenceTestAgent::RRtaData::Open(class RFile &, class TDesC16 const &)
	?Open@RRtaData@ReferenceTestAgent@@QAEHABVTDesC16@@0I@Z @ 15 NONAME ; int ReferenceTestAgent::RRtaData::Open(class TDesC16 const &, class TDesC16 const &, unsigned int)
	?Read@RRtaData@ReferenceTestAgent@@QAEHAAVTDes8@@H@Z @ 16 NONAME ; int ReferenceTestAgent::RRtaData::Read(class TDes8 &, int)
	?Seek@RRtaData@ReferenceTestAgent@@QBEHW4TSeek@@AA_J@Z @ 17 NONAME ; int ReferenceTestAgent::RRtaData::Seek(enum TSeek, long long &) const
	??0RRtaManager@ReferenceTestAgent@@QAE@XZ @ 18 NONAME ; ReferenceTestAgent::RRtaManager::RRtaManager(void)
	?Connect@RRtaManager@ReferenceTestAgent@@QAEHXZ @ 19 NONAME ; int ReferenceTestAgent::RRtaManager::Connect(void)
	?CopyFile@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@0@Z @ 20 NONAME ; int ReferenceTestAgent::RRtaManager::CopyFile(class TDesC16 const &, class TDesC16 const &) const
	?DeleteFile@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 21 NONAME ; int ReferenceTestAgent::RRtaManager::DeleteFile(class TDesC16 const &) const
	?GetDir@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@IIAAPAVCDir@@1@Z @ 22 NONAME ; int ReferenceTestAgent::RRtaManager::GetDir(class TDesC16 const &, unsigned int, unsigned int, class CDir * &, class CDir * &) const
	?GetDir@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@IIAAPAVCDir@@@Z @ 23 NONAME ; int ReferenceTestAgent::RRtaManager::GetDir(class TDesC16 const &, unsigned int, unsigned int, class CDir * &) const
	?GetDir@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@VTUidType@@IAAPAVCDir@@@Z @ 24 NONAME ; int ReferenceTestAgent::RRtaManager::GetDir(class TDesC16 const &, class TUidType, unsigned int, class CDir * &) const
	?MkDir@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 25 NONAME ; int ReferenceTestAgent::RRtaManager::MkDir(class TDesC16 const &) const
	?MkDirAll@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 26 NONAME ; int ReferenceTestAgent::RRtaManager::MkDirAll(class TDesC16 const &) const
	?RenameFile@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@0@Z @ 27 NONAME ; int ReferenceTestAgent::RRtaManager::RenameFile(class TDesC16 const &, class TDesC16 const &) const
	?RmDir@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 28 NONAME ; int ReferenceTestAgent::RRtaManager::RmDir(class TDesC16 const &) const
	?RenameDir@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@0@Z @ 29 NONAME ; int ReferenceTestAgent::RRtaManager::RenameDir(class TDesC16 const &, class TDesC16 const &) const
	?GetAttribute@RRtaManager@ReferenceTestAgent@@QBEHABVTVirtualPathPtr@ContentAccess@@HAAH@Z @ 30 NONAME ; int ReferenceTestAgent::RRtaManager::GetAttribute(class ContentAccess::TVirtualPathPtr const &, int, int &) const
	?GetAttributeSet@RRtaManager@ReferenceTestAgent@@QBEHABVTVirtualPathPtr@ContentAccess@@AAVRAttributeSet@4@@Z @ 31 NONAME ; int ReferenceTestAgent::RRtaManager::GetAttributeSet(class ContentAccess::TVirtualPathPtr const &, class ContentAccess::RAttributeSet &) const
	?GetStringAttribute@RRtaManager@ReferenceTestAgent@@QBEHABVTVirtualPathPtr@ContentAccess@@HAAVTDes16@@@Z @ 32 NONAME ; int ReferenceTestAgent::RRtaManager::GetStringAttribute(class ContentAccess::TVirtualPathPtr const &, int, class TDes16 &) const
	?GetStringAttributeSet@RRtaManager@ReferenceTestAgent@@QBEHABVTVirtualPathPtr@ContentAccess@@AAVRStringAttributeSet@4@@Z @ 33 NONAME ; int ReferenceTestAgent::RRtaManager::GetStringAttributeSet(class ContentAccess::TVirtualPathPtr const &, class ContentAccess::RStringAttributeSet &) const
	??0RRtaContent@ReferenceTestAgent@@QAE@XZ @ 34 NONAME ; ReferenceTestAgent::RRtaContent::RRtaContent(void)
	?CloseContainer@RRtaContent@ReferenceTestAgent@@QBEHXZ @ 35 NONAME ; int ReferenceTestAgent::RRtaContent::CloseContainer(void) const
	?GetAttribute@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@HAAH@Z @ 36 NONAME ; int ReferenceTestAgent::RRtaContent::GetAttribute(class TDesC16 const &, int, int &) const
	?GetAttributeSet@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@AAVRAttributeSet@ContentAccess@@@Z @ 37 NONAME ; int ReferenceTestAgent::RRtaContent::GetAttributeSet(class TDesC16 const &, class ContentAccess::RAttributeSet &) const
	?GetEmbeddedObjectsL@RRtaContent@ReferenceTestAgent@@QBEXAAV?$RStreamablePtrArray@VCEmbeddedObject@ContentAccess@@@ContentAccess@@@Z @ 38 NONAME ; void ReferenceTestAgent::RRtaContent::GetEmbeddedObjectsL(class ContentAccess::RStreamablePtrArray<class ContentAccess::CEmbeddedObject> &) const
	?GetEmbeddedObjectsL@RRtaContent@ReferenceTestAgent@@QBEXAAV?$RStreamablePtrArray@VCEmbeddedObject@ContentAccess@@@ContentAccess@@W4TEmbeddedType@4@@Z @ 39 NONAME ; void ReferenceTestAgent::RRtaContent::GetEmbeddedObjectsL(class ContentAccess::RStreamablePtrArray<class ContentAccess::CEmbeddedObject> &, enum ContentAccess::TEmbeddedType) const
	?GetStringAttribute@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@HAAVTDes16@@@Z @ 40 NONAME ; int ReferenceTestAgent::RRtaContent::GetStringAttribute(class TDesC16 const &, int, class TDes16 &) const
	?GetStringAttributeSet@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@AAVRStringAttributeSet@ContentAccess@@@Z @ 41 NONAME ; int ReferenceTestAgent::RRtaContent::GetStringAttributeSet(class TDesC16 const &, class ContentAccess::RStringAttributeSet &) const
	?Open@RRtaContent@ReferenceTestAgent@@QAEHAAVRFile@@@Z @ 42 NONAME ; int ReferenceTestAgent::RRtaContent::Open(class RFile &)
	?Open@RRtaContent@ReferenceTestAgent@@QAEHABVTDesC16@@I@Z @ 43 NONAME ; int ReferenceTestAgent::RRtaContent::Open(class TDesC16 const &, unsigned int)
	?OpenContainer@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 44 NONAME ; int ReferenceTestAgent::RRtaContent::OpenContainer(class TDesC16 const &) const
	?Search@RRtaContent@ReferenceTestAgent@@QBEHAAV?$RStreamablePtrArray@VCEmbeddedObject@ContentAccess@@@ContentAccess@@ABVTDesC8@@H@Z @ 45 NONAME ; int ReferenceTestAgent::RRtaContent::Search(class ContentAccess::RStreamablePtrArray<class ContentAccess::CEmbeddedObject> &, class TDesC8 const &, int) const
	?CopyFile@RRtaManager@ReferenceTestAgent@@QBEHAAVRFile@@ABVTDesC16@@@Z @ 46 NONAME ; int ReferenceTestAgent::RRtaManager::CopyFile(class RFile &, class TDesC16 const &) const
	?DeleteRightsByKeyL@RRtaRights@ReferenceTestAgent@@QAEXABVTDesC8@@@Z @ 47 NONAME ; void ReferenceTestAgent::RRtaRights::DeleteRightsByKeyL(class TDesC8 const &)
	?EraseDeleteKeyL@RRtaRights@ReferenceTestAgent@@QAEXABVTDesC8@@@Z @ 48 NONAME ; void ReferenceTestAgent::RRtaRights::EraseDeleteKeyL(class TDesC8 const &)
	?Read@RRtaData@ReferenceTestAgent@@QAEH_JAAVTDes8@@H@Z @ 49 NONAME ; int ReferenceTestAgent::RRtaData::Read(long long, class TDes8 &, int)
	?ReloadRightsDatabaseL@RRtaRights@ReferenceTestAgent@@QAEXABVTDesC16@@@Z @ 50 NONAME ; void ReferenceTestAgent::RRtaRights::ReloadRightsDatabaseL(class TDesC16 const &)
	?GetAttribute@RRtaManager@ReferenceTestAgent@@QBEHHAAHAAVRFile@@ABVTDesC16@@@Z @ 51 NONAME ; int ReferenceTestAgent::RRtaManager::GetAttribute(int, int &, class RFile &, class TDesC16 const &) const
	?GetAttributeSet@RRtaManager@ReferenceTestAgent@@QBEHAAVRAttributeSet@ContentAccess@@AAVRFile@@ABVTDesC16@@@Z @ 52 NONAME ; int ReferenceTestAgent::RRtaManager::GetAttributeSet(class ContentAccess::RAttributeSet &, class RFile &, class TDesC16 const &) const
	?GetStringAttribute@RRtaManager@ReferenceTestAgent@@QBEHHAAVTDes16@@AAVRFile@@ABVTDesC16@@@Z @ 53 NONAME ; int ReferenceTestAgent::RRtaManager::GetStringAttribute(int, class TDes16 &, class RFile &, class TDesC16 const &) const
	?GetStringAttributeSet@RRtaManager@ReferenceTestAgent@@QBEHAAVRStringAttributeSet@ContentAccess@@AAVRFile@@ABVTDesC16@@@Z @ 54 NONAME ; int ReferenceTestAgent::RRtaManager::GetStringAttributeSet(class ContentAccess::RStringAttributeSet &, class RFile &, class TDesC16 const &) const
	?CancelNotifyStatusChange@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 55 NONAME ; int ReferenceTestAgent::RRtaContent::CancelNotifyStatusChange(class TDesC16 const &) const
	?DisplayInfoL@RRtaManager@ReferenceTestAgent@@QBEXW4TDisplayInfo@ContentAccess@@ABVTVirtualPathPtr@4@@Z @ 56 NONAME ; void ReferenceTestAgent::RRtaManager::DisplayInfoL(enum ContentAccess::TDisplayInfo, class ContentAccess::TVirtualPathPtr const &) const
	?AgentSpecificCommand@RRtaManager@ReferenceTestAgent@@QBEHHABVTDesC8@@AAVTDes8@@@Z @ 57 NONAME ; int ReferenceTestAgent::RRtaManager::AgentSpecificCommand(int, class TDesC8 const &, class TDes8 &) const
	?CancelNotifyStatusChange@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 58 NONAME ; int ReferenceTestAgent::RRtaManager::CancelNotifyStatusChange(class TDesC16 const &) const
	?CancelRequestRights@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@@Z @ 59 NONAME ; int ReferenceTestAgent::RRtaContent::CancelRequestRights(class TDesC16 const &) const
	?DisplayInfoL@RRtaContent@ReferenceTestAgent@@QBEXW4TDisplayInfo@ContentAccess@@ABVTDesC16@@@Z @ 60 NONAME ; void ReferenceTestAgent::RRtaContent::DisplayInfoL(enum ContentAccess::TDisplayInfo, class TDesC16 const &) const
	?NotifyStatusChangeL@RRtaManager@ReferenceTestAgent@@QBEXABVTDesC16@@W4TEventMask@ContentAccess@@@Z @ 61 NONAME ; void ReferenceTestAgent::RRtaManager::NotifyStatusChangeL(class TDesC16 const &, enum ContentAccess::TEventMask) const
	?DisplayManagementInfoL@RRtaManager@ReferenceTestAgent@@QBEXXZ @ 62 NONAME ; void ReferenceTestAgent::RRtaManager::DisplayManagementInfoL(void) const
	?AgentSpecificCommand@RRtaContent@ReferenceTestAgent@@QBEHHABVTDesC8@@AAVTDes8@@@Z @ 63 NONAME ; int ReferenceTestAgent::RRtaContent::AgentSpecificCommand(int, class TDesC8 const &, class TDes8 &) const
	?SetProperty@RRtaData@ReferenceTestAgent@@QBEHW4TAgentProperty@ContentAccess@@H@Z @ 64 NONAME ; int ReferenceTestAgent::RRtaData::SetProperty(enum ContentAccess::TAgentProperty, int) const
	?SetProperty@RRtaManager@ReferenceTestAgent@@QBEHW4TAgentProperty@ContentAccess@@H@Z @ 65 NONAME ; int ReferenceTestAgent::RRtaManager::SetProperty(enum ContentAccess::TAgentProperty, int) const
	?DisplayInfoL@RRtaManager@ReferenceTestAgent@@QBEXW4TDisplayInfo@ContentAccess@@AAVRFile@@ABVTDesC16@@@Z @ 66 NONAME ; void ReferenceTestAgent::RRtaManager::DisplayInfoL(enum ContentAccess::TDisplayInfo, class RFile &, class TDesC16 const &) const
	?SetProperty@RRtaContent@ReferenceTestAgent@@QBEHW4TAgentProperty@ContentAccess@@H@Z @ 67 NONAME ; int ReferenceTestAgent::RRtaContent::SetProperty(enum ContentAccess::TAgentProperty, int) const
	?RequestRightsL@RRtaContent@ReferenceTestAgent@@QBEXABVTDesC16@@@Z @ 68 NONAME ; void ReferenceTestAgent::RRtaContent::RequestRightsL(class TDesC16 const &) const
	?NotifyStatusChangeL@RRtaContent@ReferenceTestAgent@@QBEXW4TEventMask@ContentAccess@@ABVTDesC16@@@Z @ 69 NONAME ; void ReferenceTestAgent::RRtaContent::NotifyStatusChangeL(enum ContentAccess::TEventMask, class TDesC16 const &) const
	?GetWmdrmAttribute@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@HAAH@Z @ 70 NONAME ; int ReferenceTestAgent::RRtaContent::GetWmdrmAttribute(class TDesC16 const &, int, int &) const
	?GetWmdrmStringAttribute@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@HAAVTDes16@@@Z @ 71 NONAME ; int ReferenceTestAgent::RRtaContent::GetWmdrmStringAttribute(class TDesC16 const &, int, class TDes16 &) const
	?GetStringAttribute@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC8@@HAAVTDes16@@@Z @ 72 NONAME ; int ReferenceTestAgent::RRtaManager::GetStringAttribute(class TDesC8 const &, int, class TDes16 &) const
	?GetWmdrmAttributeSet@RRtaData@ReferenceTestAgent@@QBEHAAVRAttributeSet@ContentAccess@@@Z @ 73 NONAME ; int ReferenceTestAgent::RRtaData::GetWmdrmAttributeSet(class ContentAccess::RAttributeSet &) const
	?GetWmdrmStringAttribute@RRtaData@ReferenceTestAgent@@QBEHHAAVTDes16@@@Z @ 74 NONAME ; int ReferenceTestAgent::RRtaData::GetWmdrmStringAttribute(int, class TDes16 &) const
	?GetWmdrmAttributeSet@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@AAVRAttributeSet@ContentAccess@@@Z @ 75 NONAME ; int ReferenceTestAgent::RRtaContent::GetWmdrmAttributeSet(class TDesC16 const &, class ContentAccess::RAttributeSet &) const
	?GetWmdrmAttribute@RRtaData@ReferenceTestAgent@@QBEHHAAH@Z @ 76 NONAME ; int ReferenceTestAgent::RRtaData::GetWmdrmAttribute(int, int &) const
	?Open@RRtaData@ReferenceTestAgent@@QAEHABVTDesC8@@@Z @ 77 NONAME ; int ReferenceTestAgent::RRtaData::Open(class TDesC8 const &)
	?Open@RRtaContent@ReferenceTestAgent@@QAEHABVTDesC8@@@Z @ 78 NONAME ; int ReferenceTestAgent::RRtaContent::Open(class TDesC8 const &)
	?Read@RRtaData@ReferenceTestAgent@@QAEHABVTDesC8@@AAVTDes8@@@Z @ 79 NONAME ; int ReferenceTestAgent::RRtaData::Read(class TDesC8 const &, class TDes8 &)
	?GetAttribute@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC8@@HAAH@Z @ 80 NONAME ; int ReferenceTestAgent::RRtaManager::GetAttribute(class TDesC8 const &, int, int &) const
	?GetStringAttributeSet@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC8@@AAVRStringAttributeSet@ContentAccess@@@Z @ 81 NONAME ; int ReferenceTestAgent::RRtaManager::GetStringAttributeSet(class TDesC8 const &, class ContentAccess::RStringAttributeSet &) const
	?GetWmdrmStringAttributeSet@RRtaContent@ReferenceTestAgent@@QBEHABVTDesC16@@AAVRStringAttributeSet@ContentAccess@@@Z @ 82 NONAME ; int ReferenceTestAgent::RRtaContent::GetWmdrmStringAttributeSet(class TDesC16 const &, class ContentAccess::RStringAttributeSet &) const
	?GetAttributeSet@RRtaManager@ReferenceTestAgent@@QBEHABVTDesC8@@AAVRAttributeSet@ContentAccess@@@Z @ 83 NONAME ; int ReferenceTestAgent::RRtaManager::GetAttributeSet(class TDesC8 const &, class ContentAccess::RAttributeSet &) const
	?GetWmdrmStringAttributeSet@RRtaData@ReferenceTestAgent@@QBEHAAVRStringAttributeSet@ContentAccess@@@Z @ 84 NONAME ; int ReferenceTestAgent::RRtaData::GetWmdrmStringAttributeSet(class ContentAccess::RStringAttributeSet &) const

